@@ -90,6 +90,9 @@ class TablasVC(SQLConnector):
         self.__check_cliente_parque(val,tipo='parques')
         if val != []:
             self.clientes = []
+            
+            val = [v for v in val if v != '']
+            
     
         self.__parques = val
     
@@ -350,7 +353,7 @@ class TablasVC(SQLConnector):
                         .loc[:,['equipo','Pnom']]\
                         .sort_values(by='equipo')\
 
-            return self._crear_dict(df['equipo'],df['Pnom'])
+            return self._crear_dict(df,llave='equipo',valor='Pnom')
             
         else:
             return self.tipoequipo[es_agrup]\
@@ -1056,6 +1059,10 @@ class TablasVC(SQLConnector):
         filtro,valor = self.__check_params_nemo_uc(nemo_parque,uc)
         return self.__obtener_equipos_no_agr(filtro=filtro,valor=valor,potencia=potencia)
 
+    def consultar_agrupamiento_de_un_equipo(self,equipo,nemo_parque='',uc=''):
+        filtro,valor = self.__check_params_nemo_uc(nemo_parque,uc)
+        return self.conjuntogeneradores.query(f"{filtro} == '{valor}' & equipo == '{equipo}'")['Agrupamiento'].array[0]
+
     def consultar_cod(self,nemo_parque='',uc=''):
         filtro,valor = self.__check_params_nemo_uc(nemo_parque,uc)
         return self.__obtener_cod(filtro=filtro,valor=valor)
